Learn R Programming

banffIT (version 2.0.0)

banffIT_website: Call the online documentation

Description

This function sends the user to the online documentation for the package, which includes a description of the latest version of the package, vignettes, user guides, and a reference list of functions and help pages.

Usage

banffIT_website()

Arguments

Value

Nothing to be returned. The function opens a web page.

Examples

Run this code
{

banffIT_website()

}

Run the code above in your browser using DataLab