This function takes a dataset and returns a diagnosis for each
observation. For the function to run, the dataset must not contain any errors
that banff_launcher() would have detected. Please prefer using
banff_launcher() to run additional tests.
Usage
add_diagnoses(banff_dataset, version = NULL)
Value
A tibble object that contains additional variables with the diagnoses results.
Arguments
banff_dataset
A tibble object.
version
A character string referring the version of Banff classification.
The most recent classification is the default.
Options are "2022" (default), "2017".